@@ -195,9 +195,9 @@ class dyagram:
                 state = json.load(file)
                 try:
                     diffs = self.get_state_diff(state, self.topology) # state is the state file on record and topology is current state
-                except Exception as e:
+                except Exception:
                     tb = self.get_traceback()
-                    print(f"DIFF TB: {tb}")
+                    self.log.info(f"EXCEPTION THROWN GETTING DIFFS: {tb}")
                 # print to screen the diffs
                 print("DIFFS\n")
                 for ip in diffs:
@@ -779,7 +779,6 @@ class dyagram:
 
         elif netmiko_session.device_type == "cisco_xr":
             output = netmiko_session.send_command("show lldp")
-            print(f"OUTPUT OF SH LLDP TO GET CHASSIS ID {output}")
             return [re.search("(?<=Chassis ID:\s).*", output).group(0)]
 
 
@@ -846,7 +845,7 @@ class dyagram:
 
     def _get_lldp_neighbors_ssh_textfsm(self, netmiko_session):
         #os = self._get_os_version(netmiko_session)
-        os = self.get_device_type(netmiko_session.host)
+        os = netmiko_session.device_type
 
         lldp_neighbors_output = netmiko_session.send_command("show lldp neighbors det", use_textfsm=True)
         if type(lldp_neighbors_output) == str:
@@ -871,7 +870,7 @@ class dyagram:
     def _get_lldp_neighbors_ssh_regex(self, netmiko_session):
 
         # os = self._get_os_version(netmiko_session)
-        netmiko_session.host = os
+        os = netmiko_session.device_type
 
         lldp_neighbors_output = netmiko_session.send_command("show lldp neighbors det")
         cdp_info_json = {"hostname": self._get_hostname(netmiko_session),
@@ -993,31 +992,31 @@ class dyagram:
 
         sh_version_output = netmiko_session.send_command("show version")
         if "IOS-XE" in sh_version_output:
-            return "ios_xe"
+            return "cisco_xe"
         elif "NX-OS" in sh_version_output:
-            return "nx_os"
+            return "cisco_nxos"
         elif "IOS XR" in sh_version_output:
-            return "ios_xr"
+            return "cisco_xr"
 
         return None
 
 
     def _get_lldp_neighbor_regex_strings(self, os):
 
-        regex = {"ios_xe":
+        regex = {"cisco_xe":
                      {"system_name": r"(?<=System Name:\s).*",
                       "local_interface": r"(?<=Local Intf:\s).*",
                       "neighbor_interface": r"(?<=Port id:\s).*",
                       "chassis_id": r"(?<=^Chassis id:\s).*"},
 
-                 "nx_os":
+                 "cisco_nxos":
                      {"system_name": r"(?<=System Name:\s).*",
                       "local_interface": r"(?<=Local Port id:\s).*",
                       "neighbor_interface": r"(?<=^Port id:\s).*",
                       "chassis_id": r"(?<=^Chassis id:\s).*"
 
                       },
-                 "ios_xr":
+                 "cisco_xr":
                      {"system_name": r"(?<=System Name:\s).*",
                       "local_interface": r"(?<=Local Interface:\s).*",
                       "neighbor_interface": r"(?<=^Port id:\s).*",
